# Clickshot

[![PyPI](https://img.shields.io/pypi/v/clickshot.svg)](https://pypi.python.org/pypi/clickshot)
[![Build Status](https://travis-ci.com/sneakypete81/clickshot.svg?branch=master)](https://travis-ci.com/sneakypete81/clickshot)
[![Coverage](https://codecov.io/gh/sneakypete81/clickshot/graph/badge.svg)](https://codecov.io/gh/sneakypete81/clickshot)

A framework for easier cross-platform GUI testing.

## Installation

```sh
pip install clickshot
```

## Usage

TODO

## Development

Requires [Poetry](https://poetry.eustace.io/).

```sh
git clone https://github.com/sneakypete81/clickshot.git
poetry install
```

Then you can use the following:

```sh
  poetry run pytest # Run all unit tests
  poetry run flake8 # Run the linter
  poetry run tox    # Run all checks across all supported Python versions
  poetry shell      # Open a venv shell with your local clone installed
```
